multivitamin.applications package
=================================

Subpackages
-----------

.. toctree::

   multivitamin.applications.images
   multivitamin.applications.text

Submodules
----------

multivitamin.applications.ai\_application module
------------------------------------------------

.. automodule:: multivitamin.applications.ai_application
   :members:
   :undoc-members:
   :show-inheritance:

multivitamin.applications.utils module
--------------------------------------

.. automodule:: multivitamin.applications.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: multivitamin.applications
   :members:
   :undoc-members:
   :show-inheritance:
